API reference
=============

This page gives an overview of all public objects, functions and methods.

.. toctree::
   :maxdepth: 2

   datasets
   ensemble
   functions
   compare
   io
   kernels
   linear_model
   meta
   metrics
   nonparametric
   preprocessing
   svm
   tree
   util
